@@ -46,6 +46,7 @@ from ....models.cv.diffusion.utils import CONCAT_KEY
 from ....models.cv.diffusion.utils import CONCAT_TYPE
 from ....models.cv.diffusion.utils import HYBRID_TYPE
 from ....models.cv.diffusion.utils import CROSS_ATTN_KEY
+from ....models.cv.diffusion.cond_models import CLIPTextConditionModel
 from ....models.cv.diffusion.samplers.ddim import DDIMMixin
 from ....models.cv.diffusion.samplers.solver import DPMSolver
 from ....models.cv.diffusion.samplers.k_samplers import KSamplerMixin
@@ -126,14 +127,9 @@ class DiffusionAPI(APIMixin):
         use_amp: bool = False,
         use_half: bool = False,
     ) -> None:
-        if use_amp and use_half:
-            raise ValueError("`use_amp` & `use_half` should not be True simultaneously")
-        self.device = device
-        self.use_amp = use_amp
-        self.use_half = use_half
+        super().to(device, use_amp=use_amp, use_half=use_half)
         unconditional_cond = getattr(self.sampler, "unconditional_cond", None)
         if use_half:
-            self.m.half()
             if self.cond_model is not None:
                 self.cond_model.half()
             if self.first_stage is not None:
@@ -141,14 +137,12 @@ class DiffusionAPI(APIMixin):
             if unconditional_cond is not None:
                 unconditional_cond = unconditional_cond.half()
         else:
-            self.m.float()
             if self.cond_model is not None:
                 self.cond_model.float()
             if self.first_stage is not None:
                 self.first_stage.float()
             if unconditional_cond is not None:
                 unconditional_cond = unconditional_cond.float()
-        self.m.to(device)
         if self.cond_model is not None:
             self.cond_model.to(device)
         if self.first_stage is not None:
@@ -232,6 +226,13 @@ class DiffusionAPI(APIMixin):
         verbose: bool = True,
         **kwargs: Any,
     ) -> Tensor:
+        registered_custom = False
+        if self.cond_model is not None:
+            if isinstance(self.cond_model, CLIPTextConditionModel):
+                custom_embeddings = kwargs.get("custom_embeddings")
+                if custom_embeddings is not None:
+                    registered_custom = True
+                    self.cond_model.register_custom(custom_embeddings)
         if cond is not None:
             if self.cond_type != CONCAT_TYPE and self.cond_model is not None:
                 data = TensorInferenceData(cond, batch_size=batch_size)
@@ -380,6 +381,8 @@ class DiffusionAPI(APIMixin):
         if export_path is not None:
             save_images(concat, export_path)
         self.empty_cuda_cache()
+        if registered_custom:
+            self.cond_model.clear_custom()
         return concat
 
     @staticmethod
